# Meeting Agenda and Action Items

[google doc to meeting notes](https://docs.google.com/document/d/1Gj4BFFmzT4vQIFH8nRNhtGOJfGi515bs847rXFNPn_8/edit?tab=t.0)

## Latest Meeting Notes (Apr 25, 2025)

**Template Ideas:**

- Simple/Project structure with pixi, mkdocs, basic DMP folder setup
- Package development templates for R and Python with project toml, ruff, CodeRabbit, Code coverage

**MkDocs Components:**

- Home
- How to run code
- Where to get data
- Working notes
- Documenting symbolic links

**GitHub Actions:**

- Check for presence of rawdata, procdata, results directories
- Documentation audits
- Optional CodeRabbit integration

**Action Items:**

- Complete initial template structure ✓
- Document DMP best practices ✓
- Setup GitHub Actions workflows 🚧
- Test with real projects 🚧
